@@ -160,6 +160,10 @@ def copy_file(src_file,dest_file):
     mk_folder(get_file_folder(dest_file))
     copyfile(src_file,dest_file)    
 
+
+
+
+
 ####################################################################################################  
 def rm_file(file_name = None, folder = None, regex_pattern=None) :
   """
@@ -453,8 +457,22 @@ def join_file(input_file, output_folder , volume_size=None):
   return
   
 ####################################################################################################
+def compare_files(source, target):
+  """
+    Compare two files by MD5
+    
+    Sample:
+      compare_files('R:/Temp1/1.txt', 'R:/Temp1/2.txt') 
+      - Returns True  : two files identical
+      - Returns False : two files different
+      
+  """
+  
+  return (get_md5(source) == get_md5(target))
 
 
+####################################################################################################
+
 def base64_encode(input_file=None,output_file=None,input_data=None, output="file"):
   """
   usage  : 
@@ -669,12 +687,17 @@ if __name__ == "__main__":
   print (get_md5('R:/Temp1/disk.bin'))
   
   """
-  
+  """
   clean_folder('R:/TempVM/stage')
   #rm_folder(folder_name='R:/TempVM/stage')
-  
+  """
   """
   rm_file(file_name = 'r:/temp1/1.txt') 
   rm_file(file_name = ['r:/temp1/1.txt', 'r:/temp1/3.txt'] ) 
   rm_file(folder = 'R:/temp1', regex_pattern='\d+\.txt' ) 
-  """
\ No newline at end of file
+  """
+  
+  """
+  print (compare_files ( 'R:/TempVM/download/866c6e0a2795e52fc8c99211736a4f70.part_00001', 'R:/TempVM/upload/866c6e0a2795e52fc8c99211736a4f70.part_00000'))
+  """
+  
\ No newline at end of file
