@@ -80,11 +80,11 @@ def send_gmail (sender_account, sender_password, smtp,smtp_port,senders,receiver
 
 if __name__ == "__main__":
   config = {
-      "Subject"     : "This is Mail subject",
-      "From"        : "test_12345@tpg.com.au",
-      "To"          : "chgpnt@gmail.com",
-      "Attachments"  : ["R:/panda.jpg", "R:/tiger.jpg", "R:/baby.jpg"],
-      "Body"        : "This is Mail subject",
+      "Subject"     : "test_icc_group_email",
+      "From"        : "test_icc_group_email@gmail.com",
+      "To"          : "fan.yang36@tafensw.edu.au",
+      "Attachments" : [],
+      "Body"        : "This is a test of ICC group email",
       "smtp_host"   : "mail.tpg.com.au",
       "smtp_port"   : 465
   }
